@@ -437,7 +437,7 @@ sub upload_plugin {
 
 sub plugin_meta {
 
-    my $path = shift or confess('usage: plugin_mate(path)');
+    my $path = shift or confess('usage: plugin_meta(path)');
 
     open F, "$path/sparrow.json" or confess "can't open sparrow.json to read: $!";
     my $s = join "", <F>;
@@ -445,6 +445,8 @@ sub plugin_meta {
 
     my $spj = decode_json($s);
 
+    $spj->{plugin_type} ||= 'outthentic';
+
     return $spj;
 
 }
